==> yndenz-modules-gallery-3.0.8-045526.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [3.0.8] - 2018-11-12
### Fixed
- Full-screen slider height

## [3.0.7] - 2018-10-16
### Fixed
- Indicators position when left or right

## [3.0.6] - 2018-10-11
### Fixed
- Google stretches full-screen gallery

## [3.0.5] - 2018-10-10
### Fixed
- Slide content not allowed to overflow
- Indicators should be corresponding with slides

## [3.0.4] - 2018-10-10
### Fixed
- Gallery depends on Object Watcher

## [3.0.3] - 2018-10-10
### Fixed
- Full-screen gallery center image

## [3.0.2] - 2018-10-10
### Changed
- Drop support for LESS

### Fixed
- Full-screen gallery responsiveness

## [3.0.1] - 2018-10-03
### Fixed
- Remove console logging

## [3.0.0] - 2018-10-03
### Changed
- Code style set to WordPress standards
- Remove bootstrap dependency

## [2.3.1] - 2018-09-27
### Changed
- Translate carousel controls

## [2.3.0] - 2018-09-17
### Changed
- Only enqueue scripts when actually required

## [2.2.1] - 2018-09-06
### Fixed
- Translation context for breadcrumb

## [2.2.0] - 2018-08-30
### Added
- Context in string translation

## [2.1.0] - 2018-08-16
### Changed
- Upgrade to gulp v4 and new babel preset-env

## [2.0.4] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.8...HEAD
[3.0.8]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.7...3.0.8
[3.0.7]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.6...3.0.7
[3.0.6]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.5...3.0.6
[3.0.5]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.4...3.0.5
[3.0.4]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.3...3.0.4
[3.0.3]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.2...3.0.3
[3.0.2]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.1...3.0.2
[3.0.1]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.0...3.0.1
[3.0.0]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.3.1...3.0.0
[2.3.1]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.3.0...2.3.1
[2.3.0]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.2.1...2.3.0
[2.2.1]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.2.0...2.2.1
[2.2.0]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.1.0...2.2.0
[2.1.0]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.0.4...2.1.0
[2.0.4]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.0.3...2.0.4

==> yndenz-modules-gallery-3.0.9-b71b0b.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [3.0.9] - 2018-11-22
### Added
- Events triggering before and after sliding

## [3.0.8] - 2018-11-12
### Fixed
- Full-screen slider height

## [3.0.7] - 2018-10-16
### Fixed
- Indicators position when left or right

## [3.0.6] - 2018-10-11
### Fixed
- Google stretches full-screen gallery

## [3.0.5] - 2018-10-10
### Fixed
- Slide content not allowed to overflow
- Indicators should be corresponding with slides

## [3.0.4] - 2018-10-10
### Fixed
- Gallery depends on Object Watcher

## [3.0.3] - 2018-10-10
### Fixed
- Full-screen gallery center image

## [3.0.2] - 2018-10-10
### Changed
- Drop support for LESS

### Fixed
- Full-screen gallery responsiveness

## [3.0.1] - 2018-10-03
### Fixed
- Remove console logging

## [3.0.0] - 2018-10-03
### Changed
- Code style set to WordPress standards
- Remove bootstrap dependency

## [2.3.1] - 2018-09-27
### Changed
- Translate carousel controls

## [2.3.0] - 2018-09-17
### Changed
- Only enqueue scripts when actually required

## [2.2.1] - 2018-09-06
### Fixed
- Translation context for breadcrumb

## [2.2.0] - 2018-08-30
### Added
- Context in string translation

## [2.1.0] - 2018-08-16
### Changed
- Upgrade to gulp v4 and new babel preset-env

## [2.0.4] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.9...HEAD
[3.0.9]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.8...3.0.9
[3.0.8]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.7...3.0.8
[3.0.7]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.6...3.0.7
[3.0.6]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.5...3.0.6
[3.0.5]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.4...3.0.5
[3.0.4]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.3...3.0.4
[3.0.3]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.2...3.0.3
[3.0.2]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.1...3.0.2
[3.0.1]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/3.0.0...3.0.1
[3.0.0]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.3.1...3.0.0
[2.3.1]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.3.0...2.3.1
[2.3.0]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.2.1...2.3.0
[2.2.1]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.2.0...2.2.1
[2.2.0]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.1.0...2.2.0
[2.1.0]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.0.4...2.1.0
[2.0.4]: https://gitlab.yndenz.com/yndenz-modules/gallery/compare/2.0.3...2.0.4
